@@ -70,13 +70,15 @@ GType animation_wallpaper_plugin_get_type(void);
 
 G_END_DECLS
 
-void lw_settings(GtkWidget *widget, gpointer user_data);
+void lw_settings(gpointer user_data, gpointer data);
 void actor_set_position_full(GtkWidget *actor, gint x, gint y, gint z);
 gint read_config(Animation_WallpaperPrivate *priv);
 void save_config(Animation_WallpaperPrivate *priv);
+void run_long_timeout(AWallpaperPlugin *desktop_plugin);
 static void init_scene(AWallpaperPlugin *desktop_plugin);
 static void init_scene1(AWallpaperPlugin *desktop_plugin);
+static void init_scene2(AWallpaperPlugin *desktop_plugin);
 void create_hildon_actor(Actor *actor, AWallpaperPlugin *desktop_plugin);
 void get_sun_screen_pos(double alt, double azm, gint * x, gint * y);
-
+void show_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv);
 #endif
